ryvencore.Connection module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.Connection module

class Connection(params)

  Bases: `ryvencore.Base.Base`

  The base class for both types of connections. All data is transmitted through a connection from an output port to some connected input port.

  activated = <ryvencore.Base.Event object>
  activate()

    Causes forward propagation of information

class ExecConnection(params)

  Bases: `ryvencore.Connection.Connection`

  activate()

    Causes an update in the input port

class DataConnection(params)

  Bases: `ryvencore.Connection.Connection`

  get_val()

    Gets the value of the output port – only used in exec mode flows

  activate(data=None)

    Passes data to the input port and causes update